@@ -1,5 +1,5 @@
 package Yancy::Backend::Pg;
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 # ABSTRACT: A backend for Postgres using Mojo::Pg
 
 #pod =head1 SYNOPSIS
@@ -112,10 +112,11 @@ our $VERSION = '1.005';
 #pod =cut
 
 use Mojo::Base '-base';
+use Mojo::Promise;
 use Scalar::Util qw( looks_like_number blessed );
 BEGIN {
-    eval { require Mojo::Pg; Mojo::Pg->VERSION( 3 ); 1 }
-        or die "Could not load Pg backend: Mojo::Pg version 3 or higher required\n";
+    eval { require Mojo::Pg; Mojo::Pg->VERSION( 4.03 ); 1 }
+        or die "Could not load Pg backend: Mojo::Pg version 4.03 or higher required\n";
 }
 
 has pg =>;
@@ -141,21 +142,40 @@ sub new {
     return $class->SUPER::new( %vars );
 }
 
+sub _id_field {
+    my ( $self, $coll ) = @_;
+    return $self->collections->{ $coll }{ 'x-id-field' } || 'id';
+}
+
 sub create {
     my ( $self, $coll, $params ) = @_;
-    my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
+    my $id_field = $self->_id_field( $coll );
     return $self->pg->db->insert( $coll, $params, { returning => $id_field } )->hash->{ $id_field };
 }
 
+sub create_p {
+    my ( $self, $coll, $params ) = @_;
+    my $id_field = $self->_id_field( $coll );
+    return $self->pg->db->insert_p( $coll, $params, { returning => $id_field } )
+        ->then( sub { shift->hash->{ $id_field } } );
+}
+
 sub get {
     my ( $self, $coll, $id ) = @_;
-    my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
+    my $id_field = $self->_id_field( $coll );
     return $self->pg->db->select( $coll, undef, { $id_field => $id } )->hash;
 }
 
-sub list {
+sub get_p {
+    my ( $self, $coll, $id ) = @_;
+    my $id_field = $self->_id_field( $coll );
+    my $db = $self->pg->db;
+    return $db->select_p( $coll, undef, { $id_field => $id } )
+        ->then( sub { shift->hash } );
+}
+
+sub _list_sqls {
     my ( $self, $coll, $params, $opt ) = @_;
-    $params ||= {}; $opt ||= {};
     my $pg = $self->pg;
     my ( $query, @params ) = $pg->abstract->select( $coll, undef, $params, $opt->{order_by} );
     my ( $total_query, @total_params ) = $pg->abstract->select( $coll, [ \'COUNT(*) as total' ], $params );
@@ -168,25 +188,61 @@ sub list {
         }
     }
     #; say $query;
+    return ( $query, $total_query, @params );
+}
+
+sub list {
+    my ( $self, $coll, $params, $opt ) = @_;
+    $params ||= {}; $opt ||= {};
+    my $pg = $self->pg;
+    my ( $query, $total_query, @params ) = $self->_list_sqls( $coll, $params, $opt );
     return {
         items => $pg->db->query( $query, @params )->hashes,
-        total => $pg->db->query( $total_query, @total_params )->hash->{total},
+        total => $pg->db->query( $total_query, @params )->hash->{total},
     };
+}
 
+sub list_p {
+    my ( $self, $coll, $params, $opt ) = @_;
+    $params ||= {}; $opt ||= {};
+    my $pg = $self->pg;
+    my ( $query, $total_query, @params ) = $self->_list_sqls( $coll, $params, $opt );
+    my $items_p = $pg->db->query_p( $query, @params )->then( sub { shift->hashes } );
+    my $total_p = $pg->db->query_p( $total_query, @params )
+        ->then( sub { shift->hash->{total} } );
+    return Mojo::Promise->all( $items_p, $total_p )
+        ->then( sub {
+            my ( $items, $total ) = @_;
+            return { items => $items->[0], total => $total->[0] };
+        } );
 }
 
 sub set {
     my ( $self, $coll, $id, $params ) = @_;
-    my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
+    my $id_field = $self->_id_field( $coll );
     return !!$self->pg->db->update( $coll, $params, { $id_field => $id } )->rows;
 }
 
+sub set_p {
+    my ( $self, $coll, $id, $params ) = @_;
+    my $id_field = $self->_id_field( $coll );
+    return $self->pg->db->update_p( $coll, $params, { $id_field => $id } )
+        ->then( sub { !!shift->rows } );
+}
+
 sub delete {
     my ( $self, $coll, $id ) = @_;
-    my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
+    my $id_field = $self->_id_field( $coll );
     return !!$self->pg->db->delete( $coll, { $id_field => $id } )->rows;
 }
 
+sub delete_p {
+    my ( $self, $coll, $id ) = @_;
+    my $id_field = $self->_id_field( $coll );
+    return $self->pg->db->delete_p( $coll, { $id_field => $id } )
+        ->then( sub { !!shift->rows } );
+}
+
 sub read_schema {
     my ( $self ) = @_;
     my $database = $self->pg->db->query( 'SELECT current_schema()' )->array->[0];
@@ -306,7 +362,7 @@ Yancy::Backend::Pg - A backend for Postgres using Mojo::Pg
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 SYNOPSIS
 
